# coding: utf-8
from os.path import abspath
from os.path import dirname
from os.path import join
import re

from pkg_resources import Requirement
from setuptools import find_packages
from setuptools import setup


_COMMENT_RE = re.compile(r'(^|\s)+#.*$')


def _get_requirements(file_path):
    print(file_path)
    with open(file_path, 'r') as file:
        for line in file:
            line = _COMMENT_RE.sub('', line)
            line = line.strip()
            if line.startswith('-r '):
                yield from _get_requirements(
                    join(dirname(abspath(file_path)), line[3:])
                )
            elif line:
                req = Requirement(line)
                req_str = f'{req.name}{req.specifier}'
                if req.marker:
                    req_str += f'; {req.marker}'
                yield req_str


def main():
    setup(
        name='m3-dev-utils',
        author='Andrey Chagochkin',
        author_email='andrey.chagochkin@bars-open.ru',
        description=(
            u'Инструментарий разработчика веб-приложений на платформе M3.'
        ),
        url=(
            'https://stash.bars-open.ru/users/andrey.chagochkin/repos/'
            'm3-dev-utils'
        ),
        package_dir={'': 'src'},
        packages=find_packages('src'),
        include_package_data=True,
        dependency_links=(
            'https://pypi.bars-open.ru/simple/m3-builder',
        ),
        setup_requires=(
            'm3-builder>=1.1.1,<2',
        ),
        install_requires=tuple(_get_requirements('requirements/prod.txt')),
        set_build_info=dirname(__file__),
    )


if __name__ == '__main__':
    main()
